<?php
/*
Plugin Name: WooCommerce Grid/List View Switcher (EasyToolsWP)
Description: A plugin to switch between grid and list views in WooCommerce.
Version: 1.0
Author: EasyToolsWP.com
Author URI: https://www.easytoolswp.com
*/

// Security check to prevent direct access
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Include necessary files and scripts
function custom_view_switcher_enqueue_scripts() {
    wp_enqueue_style('custom-view-switcher-css', plugin_dir_url(__FILE__) . 'style.css');
    wp_enqueue_script('custom-view-switcher-js', plugin_dir_url(__FILE__) . 'script.js', array('jquery'), '1.0', true);
}
add_action('wp_enqueue_scripts', 'custom_view_switcher_enqueue_scripts');

// Add buttons to switch views
function custom_view_switcher_buttons() {
    echo '<div class="view-switcher">';
    echo '<button id="grid-view" class="active">Grid</button>';
    echo '<button id="list-view">List</button>';
    echo '</div>';
}
add_action('woocommerce_before_shop_loop', 'custom_view_switcher_buttons');

// Add body classes for view types
function custom_view_switcher_body_class($classes) {
    if (isset($_COOKIE['shop_view']) && $_COOKIE['shop_view'] == 'list') {
        $classes[] = 'list-view';
    } else {
        $classes[] = 'grid-view';
    }
    return $classes;
}
add_filter('body_class', 'custom_view_switcher_body_class');

// Add a class to products in list view
function custom_view_switcher_product_classes($classes, $class, $product_id) {
    if (isset($_COOKIE['shop_view']) && $_COOKIE['shop_view'] == 'list') {
        $classes[] = 'list-view-product';
    }
    return $classes;
}
add_filter('post_class', 'custom_view_switcher_product_classes', 10, 3);

// Add settings for displaying products in list view
function custom_view_switcher_settings_page() {
    add_submenu_page(
        '',
        'View Switcher Settings',
        'View Switcher Settings',
        'manage_options',
        'easytoolswp_pro-settings',
        'custom_view_switcher_settings_content'
    );
}
add_action('admin_menu', 'custom_view_switcher_settings_page');

function custom_view_switcher_settings_content() {
    ?>
    <div class="wrap">
        <form method="post" action="options.php">
        <h2>WooCommerce Grid/List Productlist</h2>
            <?php settings_fields('view_switcher_options'); ?>
            <?php do_settings_sections('view_switcher_options'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Hide Image</th>
                    <td><input type="checkbox" name="hide_image" <?php checked(get_option('hide_image'), 'on'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Hide Title</th>
                    <td><input type="checkbox" name="hide_title" <?php checked(get_option('hide_title'), 'on'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Hide Price</th>
                    <td><input type="checkbox" name="hide_price" <?php checked(get_option('hide_price'), 'on'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Hide Add to Cart Button</th>
                    <td><input type="checkbox" name="hide_add_to_cart" <?php checked(get_option('hide_add_to_cart'), 'on'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Hide Short Text</th>
                    <td><input type="checkbox" name="hide_short_text" <?php checked(get_option('hide_short_text'), 'on'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Image Width in List View</th>
                    <td><input type="number" name="image_width_in_list" value="<?php echo esc_attr(get_option('image_width_in_list')); ?>" /></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

function custom_view_switcher_register_settings() {
    register_setting('view_switcher_options', 'hide_image');
    register_setting('view_switcher_options', 'hide_title');
    register_setting('view_switcher_options', 'hide_price');
    register_setting('view_switcher_options', 'hide_add_to_cart');
    register_setting('view_switcher_options', 'hide_short_text');
    register_setting('view_switcher_options', 'image_width_in_list');
}
add_action('admin_init', 'custom_view_switcher_register_settings');

// Add CSS for custom styling
function custom_view_switcher_custom_css() {
    ?>
    <style type="text/css">
        /* Adjust image width in list view */
        .list-view ul.products li.product .woocommerce-LoopProduct-link img {
            max-width: <?php echo esc_attr(get_option('image_width_in_list')); ?>px;
            height: auto;
        }

        /* Hide elements based on settings */
        <?php if (get_option('hide_image') === 'on') : ?>
            ul.products li.product .woocommerce-LoopProduct-link img {
                display: none;
            }
        <?php endif; ?>

        <?php if (get_option('hide_title') === 'on') : ?>
            ul.products li.product .woocommerce-loop-product__title {
                display: none;
            }
        <?php endif; ?>

        <?php if (get_option('hide_price') === 'on') : ?>
            ul.products li.product .price {
                display: none;
            }
        <?php endif; ?>

        <?php if (get_option('hide_add_to_cart') === 'on') : ?>
            ul.products li.product .button {
                display: none;
            }
        <?php endif; ?>

        <?php if (get_option('hide_short_text') === 'on') : ?>
            ul.products li.product .etwp-product-short-description {
                display: none;
            }
        <?php endif; ?>
    </style>
    <?php
}
add_action('wp_head', 'custom_view_switcher_custom_css');
